@@ -28,8 +28,16 @@
 #include <mkl_pardiso.h>
 #include <mkl_spblas.h>
 #include <mkl_types.h>
-//#include <omp.h>
+#if 0
+#include <omp.h>
+#else
 
+extern "C" {
+extern int    omp_get_max_threads  (void);
+extern int     omp_get_num_threads  (void);
+extern void    omp_set_num_threads (int);
+}
+#endif
 #include "rgraph.hpp"
 #include "AFunction.hpp"
 
@@ -177,37 +185,33 @@ bool SetPARDISO()
     TypeSolveMat::defaultvalue =TypeSolveMatdefaultvalue;
     return 0;
 }
-/*
-class Init {
+/*  class Init {
     public:
         Init();
 };
 
 
 
-LOADINIT(Init);
+$1 */
+
 
-Init::Init() {
-    TypeSolveMat::defaultvalue = TypeSolveMat::SparseSolver;
-    DefSparseSolver<double>::solver = buildSolver<double>;
-    DefSparseSolver<Complex>::solver = buildSolver<Complex>;
-}
-*/
 
-extern int    omp_get_max_threads  (void);
-extern int     omp_get_num_threads  (void);
-extern void    omp_set_num_threads (int);
 
 static long ffompgetnumthreads(){return omp_get_num_threads();}
 static long ffompgetmaxthreads(){return omp_get_max_threads();}
 
 static long ffompsetnumthreads(long n){omp_set_num_threads(n); return n;}
 
-void initPARDISO()
-{
+static void Load_Init() {
+  //}static void initPARDISO()
+  //{
     
     if(verbosity>1)
         cout << "\n Add: PARDISO:  defaultsolver defaultsolverPARDISO" << endl;
+    TypeSolveMat::defaultvalue = TypeSolveMat::SparseSolver;
+    DefSparseSolver<double>::solver = buildSolver<double>;
+    DefSparseSolver<Complex>::solver = buildSolver<Complex>;
+
     DefSparseSolver<double>::solver  = buildSolver;
     DefSparseSolver<Complex>::solver = buildSolver;
     DefSparseSolverSym<double>::solver  = buildSolver;
@@ -225,4 +229,5 @@ void initPARDISO()
 }
 
 
-LOADFUNC(initPARDISO);
+//LOADFUNC(initPARDISO);
+LOADFUNC(Load_Init)
