@@ -741,9 +741,9 @@ BuildSolverSuperLU(DCL_ARG_SPARSE_SOLVER(Complex,A))
 }
 
 
-class Init { public:
+/*  class Init { public:
     Init();
-};
+    };*/
 
 //  the 2 default sparse solver double and complex
 DefSparseSolver<double>::SparseMatSolver SparseMatSolver_R ; ;
@@ -761,10 +761,7 @@ bool SetSuperLU()
     return  true;
 }
 
-
-
-LOADINIT(Init);
-Init::Init()
+static void Load_Init()
 { 
   
   SparseMatSolver_R= DefSparseSolver<double>::solver;
@@ -778,3 +775,4 @@ Init::Init()
   Global.Add("defaulttoSuperLU","(",new OneOperator0<bool>(SetSuperLU));
 }
 
+LOADFUNC(Load_Init)
