@@ -376,6 +376,11 @@ SparseMatStructure& SparseMatStructure::AddMatrix(Matrice_Creuse<R> const * cons
     n = n > _M->N() ? n : _M->N();
     m = m > _M->M() ? m : _M->M();
     MatriceMorse<R> const * const M = dynamic_cast<MatriceMorse<R> const * const> (&(*_M->A));
+    if( !M ) {
+        cerr << " Err= "<< " Matrix is not morse or CSR "<< &(*_M->A) << endl;
+        ffassert(M);
+    }
+     {
     if(!sym || (sym && M->symetrique))
     {
         for(int i=0;i < M->N;++i)
@@ -390,6 +395,7 @@ SparseMatStructure& SparseMatStructure::AddMatrix(Matrice_Creuse<R> const * cons
             for(int k=M->lg[i]; k < M->lg[i+1]; ++k) if(i >= M->cl[k]) structure.insert(Z2(i,M->cl[k]));
         }
     }
+    }
     return *this;
 }
 template<class INT> SparseMatStructure& SparseMatStructure::AddArrays(const KN<INT> &I,const KN<INT> &J)
@@ -1401,13 +1407,13 @@ basicAC_F0::name_and_type  OptimIpopt::E_Ipopt::name_param[]=
 
 
 
-class Init { public:
+/*  class Init { public:
     Init();
 };
 
 static Init init;
-
-Init::Init()
+*/
+static void Load_Init()
 {
     Global.Add("IPOPT","(",new OptimIpopt(Case<no_assumption_f,no_assumption_g>()));
     Global.Add("IPOPT","(",new OptimIpopt(Case<no_assumption_f,without_constraints>()));
@@ -1737,4 +1743,5 @@ GenericConstraintFunctionDatas* GenericConstraintFunctionDatas::New(AssumptionG
  enum AssumptionF {undeff,no_assumption_f, P2_f, unavailable_hessian, mv_P2_f, quadratic_f, linear_f};
  enum AssumptionG {undefg,without_constraints, no_assumption_g, P1_g, mv_P1_g, linear_g};
  */
+LOADFUNC(Load_Init)
 
