@@ -1,5 +1,4 @@
-//ff-c++-LIBRARY-dep:   lapack
-//ff-c++-LIBRARY-dep:   blas
+//ff-c++-LIBRARY-dep:   lapack   blas
 #include "ff++.hpp"
 #include "RNM.hpp"
 #include "AFunction_ext.hpp" // Extension of "AFunction.hpp" to deal with more than 3 parameters function
@@ -29,9 +28,6 @@ typedef void VOID;
 #include "clapack.h"
 #undef real
 #undef complex 
-class Init { public:
-  Init();
-};
 
 long lapack_inv(KNM<double>* A)
 {
@@ -715,11 +711,6 @@ class OneBinaryOperatorRNM_inv : public OneOperator { public:
 };
 
 
-/* 
-class Init { public:
-  Init();
-};
-*/
 template <int INIT>
 KNM<R>* Solve(KNM<R>* a,Inverse<KNM<R >*> b) 
 {
@@ -919,12 +910,11 @@ KNM<Complex>* SolveC(KNM<Complex>* a,Inverse<KNM<Complex >*> b)
   return a;
 }
 
-LOADINIT(Init);  //  une variable globale qui serat construite  au chargement dynamique 
 
 template<class R,class A,class B> R Build2(A a,B b) {
     return R(a,b);
 }
-Init::Init(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freefem++ 
+static void Load_Init(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freefem++ 
 
   if( map_type.find(typeid(Inverse<KNM<double >* >).name() ) == map_type.end() )
     {
@@ -976,3 +966,4 @@ Init::Init(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freefem
       cout << "( load: lapack <=> fflapack , skeep ) ";
 }
 
+LOADFUNC(Load_Init)
