@@ -87,16 +87,16 @@ Mesh * SplitMesh3(Fem2D::Mesh * const & pTh)
 }
 
 //  truc pour que la fonction 
-// Init::Init() soit appele a moment du chargement dynamique
+// static void Load_Init() soit appele a moment du chargement dynamique
 // du fichier 
 //  
-class Init { public:
+/*  class Init { public:
   Init();
 };
 
-LOADINIT(Init);  //  une variable globale qui serat construite  au chargement dynamique 
+$1 */
 
-Init::Init(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freefem++ 
+static void Load_Init(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freefem++ 
   if (verbosity)
     cout << " lood: Split3  " << endl;
   Global.Add("splitmesh3","(",new OneOperator1_<Mesh *,Mesh *>(SplitMesh3));
@@ -112,3 +112,4 @@ Init::Init(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freefem
   */
 
 }
+LOADFUNC(Load_Init)
