@@ -2510,13 +2510,13 @@ AnyType  ConvexHull3D_tetg_file_Op::operator()(Stack stack)  const
 }
 
 
-class Init1 { public:
+/*  class Init1 { public:
   Init1();
 };
 
-LOADINIT(Init1)  //  une variable globale qui serat construite  au chargement dynamique 
+$1 */
 
-Init1::Init1(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freefem++ 
+static void Load_Init(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freefem++ 
   
   //if (verbosity)
   if(verbosity) cout << " load: tetgen  " << endl;
@@ -2533,3 +2533,4 @@ Init1::Init1(){  // le constructeur qui ajoute la fonction "splitmesh3"  a freef
 // a will correct this in next version ...
 #define  WITH_NO_INIT
 #include "msh3.cpp" 
+LOADFUNC(Load_Init)
