@@ -4,7 +4,7 @@
 // AUTHOR   : P. Jolivet 
 // E-MAIL   : Pierre Jolivet <pierre.jolivet@ljll.math.upmc.fr>
 //
-//ff-c++-LIBRARY-dep:  mumps parmetis ptscotch  scalapack blas  mpifc  fc mpi  pthread 
+//ff-c++-LIBRARY-dep:  mumps parmetis ptscotch scotch  scalapack blas  mpifc  fc mpi  pthread 
 //ff-c++-cpp-dep: 
 
 /* 
@@ -31,7 +31,7 @@
 #include "AFunction.hpp"
 
 // FFCS - 23/4/13 - instanciate some global symbols which are not found by default in MS MPI Fortran libraries
-#ifdef WIN32
+#ifdef _WIN32
 __declspec(dllexport) int toto;
 MPI_Fint* _imp__MPI_F_STATUS_IGNORE;
 MPI_Fint* _imp__MPI_F_STATUSES_IGNORE;
@@ -60,6 +60,7 @@ template<> struct MPI_TYPE<long>      {static const MPI_Datatype  TYPE(){return
 template<> struct MPI_TYPE<int>      {static const MPI_Datatype TYPE(){return MPI_INT;}};
 template<> struct MPI_TYPE<double>    {static const MPI_Datatype TYPE(){return MPI_DOUBLE;}};
 template<> struct MPI_TYPE<char>    {static const MPI_Datatype TYPE(){return MPI_BYTE;}};
+template<> struct MPI_TYPE<Complex>    {static const MPI_Datatype TYPE(){return MPI_DOUBLE_COMPLEX;}};
 
 
 static std::string analysis[] = {"AMD", "", "AMF", "SCOTCH", "PORD", "METIS", "QAMD", "automatic sequential", "automatic parallel", "PT-SCOTCH", "ParMetis"};
