@@ -863,7 +863,7 @@ void OnePlotFE<Mesh>::Draw(OneWindow *win)
 		plot.color(2+col);
 		uv = coef*uv;
 		l *= coef;
-		R2 dd = uv*(-0.01/l);
+		R2 dd = uv*(-kk/l);
 		R2 dn = dd.perp()*0.5;
 		if (l*10000.< kk) continue;
 		if (l < kk) 
@@ -2897,6 +2897,7 @@ void 	SetDefWin(const char *p,int & iii0,int & jjj0,int & Width,int &Height)
 }
 int main(int argc,  char** argv)
 {
+    ffapi::init(); 
     glutInit(&argc, argv);
     bool stereo=false;
     bool fullscreen = false;
