@@ -59,7 +59,18 @@ namespace Fem2D  {
 #include "R3.hpp"
 #include "Label.hpp"
 #include "HashTable.hpp"
-
+    
+inline int  randwalk(int ncas)
+{
+        const long long a = 314125421, b =1, m=  777777;
+        static long xn = 19999999%m;
+        if(ncas <=0) xn=19999999%m;
+        long long xxn = xn;
+        xn = a*xxn%m +1;
+        xn %= m;
+        return  (xn*ncas)/m;
+}
+    
   const double UnSetMesure=-1e+200;
 
 inline int maxdfon(const int *dfon){ return max(max(dfon[0],dfon[1]),max(dfon[2],dfon[3]));}
@@ -686,7 +697,19 @@ public:
     delete [] vertices;
     delete [] bnormalv;
     if(gtree) delete gtree;
-    
+      ElementConteningVertex=0;
+      TheAdjacencesLink=0;
+      BoundaryElementHeadLink=0;
+      borderelements=0;
+      elements=0;
+      vertices=0;
+      bnormalv=0;
+      gtree=0;
+      nt=(0);
+      nv=(0);
+      nbe=(0);
+      mes=(0.);
+      mesb=(0.);
   }
 
   Serialize serialize() const;
@@ -1268,8 +1291,9 @@ DataFENodeDF GenericMesh<T,B,V>::BuildDFNumbering(int ndfon[NbTypeItemElement],i
 		  {
 		      int i0=j++,i1=j++; 
 		      if(keys[i1]<keys[i0]) swap( keys[i0],keys[i1]);
-		      //typename HashTable<Key,Key>::iterator pe = 
-		     equi.add(keys[i0],keys[i1]);
+		      //typename HashTable<Key,Key>::iterator pe =
+                      if(keys[i0]< keys[i1] ) // not equal ... Add nov. 2014 
+		        equi.add(keys[i0],keys[i1]);
 		     // if(pe) assert(pe->k == keys[i0]);
 		  }
 		
@@ -1280,15 +1304,18 @@ DataFENodeDF GenericMesh<T,B,V>::BuildDFNumbering(int ndfon[NbTypeItemElement],i
 	  for (int it=0,change=1;change;it++)
 	    { 
 	    change=0;
-	    assert(it<10);
+	    ffassert(it++<100);
 	    for (typename HashTable<Key,Key>::iterator qe,pe=equi.begin() ; pe != equi.end(); ++pe)
 	      { 
-		  
-		  assert( pe->k < pe->v); 
+                  if( verbosity>9999) cout << pe->k << " " << pe->v << endl;
+		  ffassert( pe->k < pe->v);
 		  qe=equi.find(pe->v);
 		  if(qe) 
-		    { change++;
-		     assert( qe->k < qe->v);
+                  {
+                      if( verbosity>9999) cout << pe->k << " " << pe->v << " <=> " << qe->k <<endl;
+
+                     change++;
+		     ffassert( qe->k < qe->v);
 		      pe->v = qe->v;
 		  }
 	    
