@@ -148,6 +148,7 @@ inline void Check_Kn(const char * str,const char * file,int line)
 //  re-correct += sep 2007
 //  add size of the matrix in VirtualMatrix class.
 //   mars 2010 add  unset KNM case ...
+//  sept 2014  add 1/v operator  ... 
 // ----------------
 
 namespace RNM {
@@ -199,7 +200,8 @@ template<class R> class KN ;
 template<class R> class conj_KN_ ;
 template<class R> class Add_KN_;
 template<class R> class Sub_KN_;
-template<class R> class Mulc_KN_;
+template<class R> class Mulc_KN_; // vector b*a_i
+template<class R> class Divc_KN_;// vector b/a_i
 template<class R> class Add_Mulc_KN_;
 template<class R> class Mul_KNM_KN_; 
 template<class R> class DotStar_KN_;
@@ -211,7 +213,7 @@ template<class R> class if_arth_KN_;
 template<class R> class ifnot_KN_;
 template<class R,class I> class KN_ITAB; 
 
-template<class R,typename A,typename B> class F_KN_;
+template<class R,typename A,typename B,typename BB> class F_KN_;
 
 
 #ifndef ffassert
@@ -505,7 +507,13 @@ public:
    KN_& operator-=(const Mulc_KN_<R> & u) ;
    KN_& operator*=(const Mulc_KN_<R> & u) ;
    KN_& operator/=(const Mulc_KN_<R> & u) ;
-  
+ 
+    KN_& operator =(const Divc_KN_<R> & u) ;
+    KN_& operator+=(const Divc_KN_<R> & u) ;
+    KN_& operator-=(const Divc_KN_<R> & u) ;
+    KN_& operator*=(const Divc_KN_<R> & u) ;
+    KN_& operator/=(const Divc_KN_<R> & u) ;
+    
    KN_& operator =(const Add_Mulc_KN_<R> & u) ;
    KN_& operator+=(const Add_Mulc_KN_<R> & u) ;
    KN_& operator-=(const Add_Mulc_KN_<R> & u) ;
@@ -538,11 +546,11 @@ public:
    KN_& operator =(const typename VirtualMatrice<R>::solveAxeqb & Ab)  
     {*this=R(); Ab.A->Solve(*this,Ab.b);return *this;}
     
-  template<class  A,class B,class C> KN_&  operator =  (const F_KN_<A,B,C>  & u) ;
-  template<class  A,class B,class C> KN_&  operator +=  (const F_KN_<A,B,C>  & u) ;
-  template<class  A,class B,class C> KN_&  operator -=  (const F_KN_<A,B,C>  & u) ;
-  template<class  A,class B,class C> KN_&  operator /=  (const F_KN_<A,B,C>  & u) ;
-  template<class  A,class B,class C> KN_&  operator *=  (const F_KN_<A,B,C>  & u) ;
+  template<class  A,class B,class C,class D> KN_&  operator =  (const F_KN_<A,B,C,D>  & u) ;
+  template<class  A,class B,class C,class D> KN_&  operator +=  (const F_KN_<A,B,C,D>  & u) ;
+  template<class  A,class B,class C,class D> KN_&  operator -=  (const F_KN_<A,B,C,D>  & u) ;
+  template<class  A,class B,class C,class D> KN_&  operator /=  (const F_KN_<A,B,C,D>  & u) ;
+  template<class  A,class B,class C,class D> KN_&  operator *=  (const F_KN_<A,B,C,D>  & u) ;
     
    
 //   KN_& operator =(const MatriceCreuseDivKN_<R> &)  ;
@@ -994,7 +1002,9 @@ class KN :public KN_<R> { public:
         { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
    KN& operator =(const Mulc_KN_<R> & u)  
         { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
-   KN& operator =(const Add_Mulc_KN_<R> & u)  
+   KN& operator =(const Divc_KN_<R> & u)
+    { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
+   KN& operator =(const Add_Mulc_KN_<R> & u)
         { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
    KN& operator =(const if_arth_KN_<R> & u)  
         { if(this->unset()) this->set(new R[u.a.N()],u.a.N());KN_<R>::operator=(u);return *this;}
@@ -1049,7 +1059,9 @@ class KN :public KN_<R> { public:
         { KN_<R>::operator-=(u);return *this;}
    KN& operator -=(const Mulc_KN_<R> & u)  
         { KN_<R>::operator-=(u);return *this;}
-   KN& operator -=(const Add_Mulc_KN_<R> & u)  
+   KN& operator -=(const Divc_KN_<R> & u)
+    { KN_<R>::operator-=(u);return *this;}
+   KN& operator -=(const Add_Mulc_KN_<R> & u)
         { KN_<R>::operator-=(u);return *this;}
    KN& operator -=(const if_arth_KN_<R> & u)  
         { KN_<R>::operator-=(u);return *this;}
@@ -1070,7 +1082,9 @@ class KN :public KN_<R> { public:
         { KN_<R>::operator+=(u);return *this;}
    KN& operator +=(const Mulc_KN_<R> & u)  
         { KN_<R>::operator+=(u);return *this;}
-   KN& operator +=(const Add_Mulc_KN_<R> & u)  
+   KN& operator +=(const Divc_KN_<R> & u)
+    { KN_<R>::operator+=(u);return *this;}
+   KN& operator +=(const Add_Mulc_KN_<R> & u)
         { KN_<R>::operator+=(u);return *this;}
    KN& operator +=(const if_arth_KN_<R> & u)  
         { KN_<R>::operator+=(u);return *this;}
@@ -1088,6 +1102,9 @@ class KN :public KN_<R> { public:
         { KN_<R>::operator/=(u);return *this;}
    KN& operator /=(const Mulc_KN_<R> & u)  
         { KN_<R>::operator/=(u);return *this;}
+   KN& operator /=(const Divc_KN_<R> & u)
+    { KN_<R>::operator/=(u);return *this;}
+    
    KN& operator /=(const Add_Mulc_KN_<R> & u)  
         { KN_<R>::operator/=(u);return *this;}
    KN& operator /=(const if_arth_KN_<R> & u)  
@@ -1106,7 +1123,9 @@ class KN :public KN_<R> { public:
         { KN_<R>::operator*=(u);return *this;}
    KN& operator *=(const Mulc_KN_<R> & u)  
         { KN_<R>::operator*=(u);return *this;}
-   KN& operator *=(const Add_Mulc_KN_<R> & u)  
+   KN& operator *=(const Divc_KN_<R> & u)
+    { KN_<R>::operator*=(u);return *this;}
+   KN& operator *=(const Add_Mulc_KN_<R> & u)
         { KN_<R>::operator*=(u);return *this;}
    KN& operator *=(const if_arth_KN_<R> & u)  
         { KN_<R>::operator*=(u);return *this;}
@@ -1151,8 +1170,8 @@ class KN :public KN_<R> { public:
          for(long i=0,j=0;j<no;i++,j+=so) 
            this->v[i]=vo[j]; 
         delete [] vo;} }//  mars 2010
-    void destroy(){assert(this->next<0);  if(this->next++ ==-1) {delete [] this->v; this->v=0;this->n=0;}}//  mars 2010
-    void increment() {assert(this->next<0);  this->next--;}
+  void destroy(){/*assert(this->next<0);*/  if(this->next++ ==-1) {delete [] this->v; this->v=0;this->n=0;}}//  mars 2010
+  void increment() {/*assert(this->next<0);*/  this->next--;}
 };
 
 //  Array with 2 indices
@@ -1264,8 +1283,8 @@ class KNM: public KNM_<R>{ public:
      }
     
   }
-  void destroy(){assert(this->next<0);  if(this->next++ ==-1) {delete [] this->v; this->v=0;this->n=0;}} 
-  void increment() {assert(this->next<0);  this->next--;}
+  void destroy(){/*assert((bool)(this->next<0)); */ if(this->next++ ==-1) {delete [] this->v; this->v=0;this->n=0;}}
+  void increment() {/*assert((bool)(this->next<0)); */ this->next--;}
     
 //  void destroy(){delete [] this->v;this->n=0 ;}
 
@@ -1373,6 +1392,15 @@ class Mulc_KN_ { public:
 {  return outProduct_KN_<R>(a,bb,b);} 
 
  };  
+template<class R>
+class Divc_KN_ {
+    // // vector b/a_i ..
+public:
+    const KN_<const_R>  a;  const_R  b;
+    Divc_KN_(const_R  bb,const KN_<const_R> & aa) : a(aa),b(bb) {}
+  //  Divc_KN_(const Divc_KN_<R> & aa,const_R  bb) : a(aa.a),b(aa.b*bb) {}
+    Divc_KN_ operator-() const {return Divc_KN_(a,-b);}
+};  
 
 template<class R> 
 class Add_Mulc_KN_ { public:
@@ -1424,11 +1452,13 @@ template<class R> inline Sub_KN_<R> operator-(const KN_<const_R> &a,const KN_<co
 template<class R> inline Mulc_KN_<R> operator*(const KN_<const_R> &a,const R &b) 
     { return Mulc_KN_<R>(a,b);}
 template<class R> inline Mulc_KN_<R> operator/(const KN_<const_R> &a,const R &b) 
-    { return Mulc_KN_<R>(a,1/b);}
+    { return Mulc_KN_<R>(a,R(1)/b);}
 template<class R> inline Mulc_KN_<R> operator*(const R &b,const KN_<const_R> &a) 
     { return Mulc_KN_<R>(a,b);}
-template<class R> inline Mulc_KN_<R> operator-(const KN_<const_R> &a) 
-    { return Mulc_KN_<R>(a,-1);}
+template<class R> inline Divc_KN_<R> operator/(const R &b,const KN_<const_R> &a)
+{ return Divc_KN_<R>(b,a);}
+template<class R> inline Mulc_KN_<R> operator-(const KN_<const_R> &a)
+    { return Mulc_KN_<R>(a,R(-1));}
 
 
 
@@ -1462,8 +1492,11 @@ template<class R> inline bool  SameShape(const ShapeOfArray & a,const Add_KN_<R>
 template<class R> inline bool  SameShape(const ShapeOfArray & a,const Sub_KN_<R> & b) 
            { return SameShape(a,b.a) ;} 
 template<class R> inline bool  SameShape(const ShapeOfArray & a,const Mulc_KN_<R> & b) 
-           { return SameShape(a,b.a) ;} 
-template<class R> inline bool  SameShape(const ShapeOfArray & a,const DotStar_KN_<R> & b) 
+           { return SameShape(a,b.a) ;}
+template<class R> inline bool  SameShape(const ShapeOfArray & a,const Divc_KN_<R> & b)
+{ return SameShape(a,b.a) ;}
+
+template<class R> inline bool  SameShape(const ShapeOfArray & a,const DotStar_KN_<R> & b)
            { return SameShape(a,b.a) ;} 
 template<class R> inline bool  SameShape(const ShapeOfArray & a,const DotSlash_KN_<R> & b) 
            { return SameShape(a,b.a) ;} 
@@ -1544,21 +1577,22 @@ class KN_2Ptr { public:
     operator const R *() const  { return c.unset() ? (R *) ca:(R *) c ;}
     ~KN_2Ptr() { if(!a.unset() && !c.unset() ) {a=c; } } // recopy 	
 }; 
-
-template<class R,typename A,typename B=R> class  F_KN_ 
+// correct march 2015 FH ...
+// add BB type ...
+template<class R,typename A,typename B=R,typename BB=B> class  F_KN_
 { 
   public: 
-  A (*f)(B);
-  KN_<R> a;
-  long N() const {return a.N();}
-  F_KN_( A (*ff)(B),const KN_<R> & aa): f(ff),a(aa) {}
-  A operator[](long i) const { return f(a[i]);}
-  bool check(long n)  const { return  n <= a.N() || a.constant(); }
-  bool constant() const {return a.constant();}
+  A (*f)(BB);
+  KN_<B> b;
+  long N() const {return b.N();}
+  F_KN_( A (*ff)(BB),const KN_<B> & aa): f(ff),b(aa) {}
+  A operator[](long i) const { return f(b[i]);}
+  bool check(long n)  const { return  n <= b.N() || b.constant(); }
+  bool constant() const {return b.constant();}
 }; 
 
-template<class R,typename A,typename B>
-inline bool  SameShape(const ShapeOfArray & a,const F_KN_<R,A,B>  & b) 
+template<class R,typename A,typename B,typename BB>
+inline bool  SameShape(const ShapeOfArray & a,const F_KN_<R,A,B,BB>  & b)
            { return  !a.step || b.constant()  || a.n == b.N() ;} 
            
 #include "RNM_tpl.hpp"
