@@ -29,13 +29,22 @@ template<class T> inline T Min (const T &a,const T & b,const T & c){return Min(M
 #include <algorithm>
 #include <complex>
 
+// ALH - 21/10/13 - R1.hpp needs cmath and it does include it, but since R1.hpp is only included as part of namespace
+// Fem2D, we need to make sure that cmath is called as part of the default namespace, otherwise we will get "error:
+// ‘::acos’ has not been declared" and such.
+
+#include <cmath>
+
 // definition R
 namespace Fem2D 
 {
+
 inline double norm(double x){return x*x;} 
 inline float norm(float x){return x*x;}
 template<class T> T  norm(const complex<T> &x){return std::norm(x);}
 
+  // ALH - These include files are located inside the namespace definition on purpose?
+
 #include "R1.hpp"
 #include "R2.hpp"
 #include "R3.hpp"
@@ -560,8 +569,10 @@ private:
   int *BoundaryAdjacencesHead;
   int *BoundaryAdjacencesLink; 
   int *TriangleConteningVertex;       
-  // no copy
+
+  // <<no_mesh_copy>> the copy constructor for Mesh is kept private on purpose
   Mesh(const Mesh &);
+
   void operator=(const Mesh &);       
 };
 
@@ -633,7 +644,7 @@ void  HeapSort(T *c,T1 *c1,T2 *c2,long n)
 }
 
  inline   int numSubTVertex(int N,int i,int j)
-    {  //  i,j  coordonne barycentre * N dans l'eleent de reference.
+    {  //  i,j  coordonne barycentre * N dans l'eleùent de reference.
 	i=i+j; // numerotation / diag  
 	// i,j 
 	assert(j<=i && 0<= j); 
