@@ -30,7 +30,26 @@
 
 #include "config-wrapper.h"
 
+#include <cmath>
 #include <complex>
+//  put here some def dur to c++11 
+// problem with mixed with using namespace std; 
+// to correct bug in g++ v 4.8.1 add std
+#ifdef _WIN32
+#define NM_STD std::
+#else
+#define NM_STD 
+#endif
+long isNaN(double x){return NM_STD isnan(x);}
+long isInf(double x){return NM_STD isinf(x);}
+long isNormal(double x){return std::isnormal(x);}
+#ifdef HAVE_JN
+double myyn(long n, double x){ return yn((int)n,x);}
+double myjn(long n, double x){ return jn((int) n,x);}
+#endif
+//int  ShowAlloc(const char *s, size_t lg);
+
+// F. Hecht fev. 2015 ...
 #include "AFunction.hpp"
 #include <cstdarg>
 #include <cstring>
@@ -871,10 +890,6 @@ C_F0  formalMatDet(const basicAC_F0 &args)
     
 }
 
-#ifdef HAVE_JN
-double myyn(long n, double x){ return yn((int)n,x);}
-double myjn(long n, double x){ return jn((int) n,x);}
-#endif
 //  Add juin  2007 
 template<class A,class B=A,class R=A>
 struct evalE_mul {
@@ -945,13 +960,9 @@ inline long fftime()
 
 long atoi(string* p) {return atoi(p->c_str());}// add march 2010
 double atof(string* p) {return atof(p->c_str());}// add march 2010
-double NaN(string* p) {return nan(p->c_str());}// add march 2012
+double NaN(string* p) {
+return nan(p->c_str());}// add march 2012
 double NaN() {return nan("");}// add march 2012
-
-long isNaN(double x){return isnan(x);}
-long isInf(double x){return isinf(x);}
-long isNormal(double x){return isnormal(x);}
-//int  ShowAlloc(const char *s, size_t lg);
 int ShowAlloc(const char *s,size_t & lg); 
 long ShowAlloc1(string *  s,long * np) { size_t lg; long  n= ShowAlloc(s->c_str(),lg); *np=lg; return n;}
 long ShowAlloc1(string *  s) { size_t lg; long  n= ShowAlloc(s->c_str(),lg); return n;}
@@ -1427,10 +1438,10 @@ void Init_map_type()
     Global.Add("square","(",new OneOperator1<long,long,E_F_F0<long,const long &> >(Square));// add FH Mai 2011
     Global.Add("square","(",new OneOperator1<double,double,E_F_F0<double,const double &> >(Square));
     Global.Add("square","(",new OneOperator1<Complex,Complex,E_F_F0<Complex,const Complex &> >(Square));// add FH Mai 2011
- //add for Olivier FH July 2017
-    Global.Add("sqr","(",new OneOperator1<long,long,E_F_F0<long,const long &> >(Square));// add FH Mai 2011
+ //add for Olivier FH July 2014
+    Global.Add("sqr","(",new OneOperator1<long,long,E_F_F0<long,const long &> >(Square));//
     Global.Add("sqr","(",new OneOperator1<double,double,E_F_F0<double,const double &> >(Square));
-    Global.Add("sqr","(",new OneOperator1<Complex,Complex,E_F_F0<Complex,const Complex &> >(Square));// add FH Mai 2011
+    Global.Add("sqr","(",new OneOperator1<Complex,Complex,E_F_F0<Complex,const Complex &> >(Square));//
 
      Global.Add("round","(",new OneOperator1<double>(round)); // add june 2007
      Global.Add("lround","(",new OneOperator1<long,double>(lround)); // add june 2007
@@ -1502,7 +1513,9 @@ void Init_map_type()
      Global.Add("tan","(",new OneOperator1_<Complex>(tan));
      Global.Add("exp","(",new OneOperator1_<Complex>(exp));
      //Complex (* powcc  )( const  Complex &, const Complex &) =pow;
-     Global.Add("pow","(",new OneOperator2_<Complex,Complex>(pow ));
+    
+    Global.Add("pow","(",new OneBinaryOperator<Op2_pow<Complex,Complex,Complex> >);
+                //new OneOperator2_<Complex,Complex>(pow ));
      Global.Add("sqrt","(",new OneOperator1_<Complex>(sqrt,0));
      Global.Add("conj","(",new OneOperator1_<Complex>(conj,0));
      Global.Add("conj","(",new OneOperator1_<double>(RNM::conj,1));
@@ -1611,34 +1624,53 @@ typedef MyMap<String,String> MyMapSS;
  } 
 static addingInitFunct TheaddingInitFunct(-10000,Init_map_type); 
 
-C_F0  opVI::code2(const basicAC_F0 &args) const      
+C_F0  opVI::code2(const basicAC_F0 &args) const
 {
     Expression p=args[1];
-    if ( ! p->EvaluableWithOutStack() ) 
-    { 
-	bool bb=p->EvaluableWithOutStack();
-	//cout << bb << " " <<  * p <<  endl;
-	CompileError(" [...][p], The p must be a constant , sorry");}
-        long pv = GetAny<long>((*p)(NullStack));
+    if ( ! p->EvaluableWithOutStack() )
+    {
+        bool bb=p->EvaluableWithOutStack();
+        //cout << bb << " " <<  * p <<  endl;
+        CompileError(" [...][p], The p must be a constant , sorry");
+    }
+    int pv = GetAny<long>((*p)(NullStack));
     bool ta =args[0].left()==atype<TransE_Array>();
     const TransE_Array * tea=0;
     const E_Array * ea=0;
-	if( ta)  tea = dynamic_cast<const TransE_Array*>((Expression) args[0]);
+    if( ta)  tea = dynamic_cast<const TransE_Array*>((Expression) args[0]);
     else ea = dynamic_cast<const E_Array*>((Expression) args[0]);
     assert( ea || tea );
     const E_Array & a=  ta ? *tea->v : *ea;
-   // cout << " pv =" << pv << " size = "<< a.size() << endl;
-    if(!(pv >=0 && pv <a.size()))
-    {
-      cerr << "\n\nerror [ ... ][" << pv <<" ] " << " the  size of [ ...]  is "<< a.size() << endl;
-      lgerror(" bound of  [ .., .. , ..][ . ] operation  ");
-    }
+    // cout << " pv =" << pv << " size = "<< a.size() << endl;
     
     //ffassert(pv >=0 && pv <a.size());
+    if(tea){
+        AC_F0  v  ;
+        for (int i=0;i<a.size();++i)
+        {
+            const E_Array * li=  dynamic_cast<const E_Array *>(a[i].LeftValue());
+            ffassert(li && (li->size() >pv));
+            
+            const C_F0 vi = TryConj( (*li)[pv]);
+            if(i==0) v=vi;
+            else v+= vi;
+            
+        }
+        
+        return C_F0(TheOperators,"[]",v);
+        
+    }
+    
+    if(!(pv >=0 && pv <a.size()))
+    {
+        cerr << "\n\nerror [ ... ][" << pv <<" ] " << " the  size of [ ...]  is "<< a.size() << endl;
+        lgerror(" bound of  [ .., .. , ..][ . ] operation  ");
+    }
+    
     return (* a.v)[pv];
 }
 
-C_F0  opDot::code2(const basicAC_F0 &args) const      
+C_F0  opDot::code2(const basicAC_F0 &args) const
 {
     bool ta =args[0].left()==atype<TransE_Array>();
     bool tb = args[1].left()==atype<TransE_Array>();
