@@ -44,7 +44,7 @@
 #include "rgraph.hpp"
 #include "InitFunct.hpp"
 
-queue<pair<const E_Routine*,int> > debugstack;
+vector<pair<const E_Routine*,int> > *debugstack=0;
 
 
 class vectorOfInst : public  E_F0mps { public:
@@ -112,7 +112,7 @@ OneOperator::pair_find OneOperator::FindWithOutCast(const ArrayOfaType & at)cons
 
 OneOperator* OneOperator::FindSameR(const ArrayOfaType & at)
  { 
-     if (!this) return 0;
+     if (this==tnull) return 0;
       OneOperator *oo,*r;
       int n=0;
       for (oo=this;oo;oo=oo->next)
@@ -607,7 +607,7 @@ void basicForEachType::AddCast(CastFunc f1,CastFunc f2,CastFunc f3,CastFunc f4,
  ostream & operator<<(ostream & f,const Polymorphic & a)
 {
   Polymorphic::const_iterator i;
-  if(!&a) return f << "Null " << endl;
+    if(&a==E_F0::tnull) return f << "Null " << endl;
   for (i=a.m.begin();i!=a.m.end();i++)
    {
     f << "   operator" << i->first << " : " << endl;
@@ -712,7 +712,8 @@ struct CleanE_Routine {
 };
 
 AnyType E_Routine::operator()(Stack s)  const  {
-   debugstack.push(pair<const E_Routine*,int>(this,TheCurrentLine));
+  //cout << " E_Routine:: push "  <<debugstack <<" " << TheCurrentLine << " " <<debugstack->size() << endl;
+   debugstack->push_back(pair<const E_Routine*,int>(this,TheCurrentLine));
    const int lgsave=BeginOffset*sizeof(void*);
    char  save[lgsave];
    AnyType ret=Nothing;
@@ -734,7 +735,7 @@ AnyType E_Routine::operator()(Stack s)  const  {
       ret=(*code)(s);  }
    catch( E_exception & e) { 
           // cout << " catch " << e.what() << " clean & throw " << endl;
-           if (e.type() == E_exception::e_return)  
+            if (e.type() == E_exception::e_return)
               ret = e.r;
            else 
               ErrorExec("E_exception: break or contine not in loop ",1);
@@ -744,17 +745,21 @@ AnyType E_Routine::operator()(Stack s)  const  {
        (*clean)(s); 
       WhereStackOfPtr2Free(s)->clean(); // FH mars 2005 
       memcpy(s,save,lgsave);  // restore 
-      TheCurrentLine=debugstack.front().second;
-      debugstack.pop();
-      throw ;             
+      TheCurrentLine=debugstack->back().second;
+      debugstack->pop_back();
+     // cout << " E_Routine:: ... pop "  <<debugstack <<" " << TheCurrentLine << " " <<debugstack->size() << endl;
+
+      throw ;
      }
   
     (*clean)(s); //  the clean is done in CleanE_Routine delete .         
    //  delete [] listparam; after return 
     memcpy(s,save,lgsave);  // restore 
-    TheCurrentLine=debugstack.front().second;
-    debugstack.pop();
-   // il faudrait que les variable locale soit detruire apres le return 
+    TheCurrentLine=debugstack->back().second;
+    debugstack->pop_back();
+   // cout << " E_Routine::  pop "  <<debugstack <<" " << TheCurrentLine << " " <<debugstack->size() << endl;
+
+   // il faudrait que les variable locale soit detruire apres le return
    // cf routine clean, pour le cas ou l'on retourne un tableau local.
    // plus safe ?????  FH.  (fait 2008)
    // mais pb si   a = f()+g()   OK les pointeurs des instruction sont detruit
@@ -858,13 +863,13 @@ void ShowDebugStack()
    cerr << "  current line = " << TheCurrentLine  
         << " mpirank " << mpirank << " / " << mpisize <<endl; 
    else
-   cerr << "  current line = " << TheCurrentLine  << endl; 
-   while ( debugstack.size() )
+   cerr << "  current line = " << TheCurrentLine  << endl;
+  if(debugstack)
+      for (int i=0; i<debugstack->size(); ++i)
      {
         
-        cerr << " call " << debugstack.front().first->name<< "  at  line " 
-             <<debugstack.front().second << endl; 
-        debugstack.pop();     
+        cerr << " call " << debugstack->at(i).first->name<< "  at  line "
+             <<debugstack->at(i).second << endl;
      }
  }
  
