@@ -39,10 +39,10 @@ namespace Fem2D
 {
 #include "R3.hpp"
 }
-int IsoLineK(double *f,Fem2D::R3 *Q,const double eps);
-int IsoLineK(double *f,Fem2D::R2 *Q,const double eps);
-int UnderIso(double *f,Fem2D::R3 Q[3][4] ,double vol[3], const double eps);
-int UnderIso(double *f,Fem2D::R2 Q[2][3] ,double area[2], const double eps);
+int IsoLineK(double *f,Fem2D::R3 *Q, double eps);
+int IsoLineK(double *f,Fem2D::R2 *Q, double eps);
+int UnderIso(double *f,Fem2D::R3 Q[3][4] ,double vol[3],  double eps);
+int UnderIso(double *f,Fem2D::R2 Q[2][3] ,double area[2],  double eps);
 
 
 
