@@ -25,3 +25,8 @@ template<class T> T *resize2(const Resize<T> & t,const long &n, const long & m)
  }
 
 template<class T> Resize<T> to_Resize( T *v){ return Resize<T>(v);}
+
+template<class T> struct  Resize1{ T v;
+    Resize1( T  vv) : v(vv) {}
+};
+template<class T> Resize1<T> to_Resize1( T v){ return Resize1<T>(v);}
