@@ -29,7 +29,7 @@
 //#pragma inline_depth(1)
 
 #include "config-wrapper.h"
-
+#include <set>
 #include <complex>
 #include "AFunction.hpp"
 #include <cstdarg>
@@ -272,7 +272,12 @@ RR get_element_si(const A &  a,const B & b,const C & c){
 template<class RR,class A,class B,class C>  
 RR get_element_lineorcol(const A &  a,const B & b,const C & c){ 
  //  cout << b << " .... " << ((*a)(SubArray(1,b),c)) << endl;;
-    return  ((*a)(b,c));}
+    if(c == ':' && (b<0 || a->N() <= b))
+            ExecError("Out of bound");
+    if(b == ':' && (c<0 || a->M() <= c))
+            ExecError("Out of bound");
+    return  ((*a)(b,c));
+    }
 
 template<class RR,class A,class B,class C>  
 RR get_element_is_(const A &  a,const B & b,const C & c){ 
@@ -335,13 +340,13 @@ public:
 	    what[i]=1;
 	  }      
 	else 
-	  CompileError(" we are waiting for scalar or vector of scalar");
+	  CompileError(" InitArrayfromArray: we are waiting for scalar or vector of scalar");
     }
     
     AnyType operator()(Stack stack)  const 
     {
-	extern void xxxx();
-	xxxx();
+	//extern void xxxx();
+	//xxxx();
       A  a=GetAny<A>((*a0)(stack));
       KN<AnyType> v(N);
       KN<int>  nn(N+1);
@@ -365,7 +370,8 @@ public:
         if (what[i]==0)
           (*a)[j]= GetAny<RR>(v[i]);
         else if (what[i]==1) 
-          (*a)(SubArray(nn[i],j)) = GetAny<KN_<RR> >(v[i]);
+          (*a)(SubArray(nn[i],j)) = GetAny<KN_<RR> >((*(tab[i]))(stack));// correct bug nov 2014
+        //  (due to resize=> pointer  change Fh
       return SetAny<R>(a);
     } 
     bool MeshIndependent() const     {return  mi;} // 
@@ -671,6 +677,7 @@ void ArrayDCL()
     Dcl_Type<DotSlash_KN_<K> >();
     Dcl_Type<Sub_KN_<K> >();
     Dcl_Type<Mulc_KN_<K> >();
+    Dcl_Type<Divc_KN_<K> >();
     Dcl_Type<Mul_KNM_KN_<K> >();
     Dcl_Type<Add_Mulc_KN_<K> *>();
     Dcl_Type<if_arth_KN_<K> *>();
@@ -899,7 +906,18 @@ class  OneOperator_2KN_ : public OneOperator {public:
         return new Op(*b);} 
     OneOperator_2KN_<K>(): OneOperator(atype<KN_<K> >(),atype<E_Array>()) { pref=-1;}
 };
-
+template<class K, class L>
+long Unique(KN<K>* const& array, KN<L>* const& val)
+{
+    std::set<L> vals;
+    for(int i = 0; i < array->n; ++i)
+        vals.insert((*array)[i]);
+    val->resize(vals.size());
+    int i = 0;
+    for(typename std::set<L>::iterator it = vals.begin(); it != vals.end(); ++it)
+        (*val)[i++] = *it;
+    return vals.size();
+}
 extern aType aaaa_knlp;
 template<class K,class Z>
 void ArrayOperator()
@@ -1080,6 +1098,7 @@ void ArrayOperator()
         new OneBinaryOperator<set_eqarray<KN<K> ,DotSlash_KN_<K> > > ,
         new OneBinaryOperator<set_eqarray<KN<K> ,Sub_KN_<K> > > ,
         new OneBinaryOperator<set_eqarray<KN<K> ,Mulc_KN_<K> > > ,
+        new OneBinaryOperator<set_eqarray<KN<K> ,Divc_KN_<K> > > ,
         new OneBinaryOperator<set_eqarray<KN<K> ,Mul_KNM_KN_<K> > > ,
         new OneBinaryOperator<set_eqarray<KN<K> ,KN_<K> > > , // Add FH juin 2005         
         new OneBinaryOperator<set_eqarraypd<KN<K> ,Add_Mulc_KN_<K>* > > , // Add FH aug 2005     
@@ -1095,6 +1114,7 @@ void ArrayOperator()
 		       new OneBinaryOperator<init_eqarray<KN<K> ,DotSlash_KN_<K> > > ,
 		       new OneBinaryOperator<init_eqarray<KN<K> ,Sub_KN_<K> > > ,
 		       new OneBinaryOperator<init_eqarray<KN<K> ,Mulc_KN_<K> > > ,
+		       new OneBinaryOperator<init_eqarray<KN<K> ,Divc_KN_<K> > > ,
 		       new OneBinaryOperator<init_eqarray<KN<K> ,Mul_KNM_KN_<K> > > ,
 		       new OneBinaryOperator<init_eqarray<KN<K> ,KN_<K> > > , // Add FH juin 2005         
 		       new OneBinaryOperator<init_eqarraypd<KN<K> ,Add_Mulc_KN_<K>* > > , // Add FH aug 2005     
@@ -1116,6 +1136,7 @@ void ArrayOperator()
         new OneBinaryOperator<set_eq_array<KN_<K> ,DotSlash_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array<KN_<K> ,Sub_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array<KN_<K> ,Mulc_KN_<K> > > ,
+        new OneBinaryOperator<set_eq_array<KN_<K> ,Divc_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array<KN_<K> ,Mul_KNM_KN_<K> > > ,
 	new OneBinaryOperator<set_eq_arraypd<KN_<K> ,if_arth_KN_<K>* > > ,
         new OneBinaryOperator<set_eq_arraypd<KN_<K> ,Add_Mulc_KN_<K>* > >  , // Add FH aug 2005    
@@ -1161,6 +1182,7 @@ void ArrayOperator()
         new OneBinaryOperator<set_eq_array_add<KN_<K> ,DotSlash_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_add<KN_<K> ,Sub_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_add<KN_<K> ,Mulc_KN_<K> > > ,
+        new OneBinaryOperator<set_eq_array_add<KN_<K> ,Divc_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_add<KN_<K> ,Mul_KNM_KN_<K> > > ,
         new OneBinaryOperator<set_eq_arraypd_add<KN_<K> ,Add_Mulc_KN_<K>* > > ,
         new OneBinaryOperator<set_eq_arraypd_add<KN_<K> ,if_arth_KN_<K>* > > ,
@@ -1190,6 +1212,7 @@ void ArrayOperator()
         new OneBinaryOperator<set_eq_array_sub<KN_<K> ,DotSlash_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_sub<KN_<K> ,Sub_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_sub<KN_<K> ,Mulc_KN_<K> > > ,
+        new OneBinaryOperator<set_eq_array_sub<KN_<K> ,Divc_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_sub<KN_<K> ,Mul_KNM_KN_<K> > > ,
         new OneBinaryOperator<set_eq_arraypd_sub<KN_<K> ,Add_Mulc_KN_<K>* > > ,
         new OneBinaryOperator<set_eq_arraypd_sub<KN_<K> ,if_arth_KN_<K>* > > ,
@@ -1214,6 +1237,7 @@ void ArrayOperator()
         new OneBinaryOperator<set_eq_array_mul<KN_<K> ,Add_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_mul<KN_<K> ,Sub_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_mul<KN_<K> ,Mulc_KN_<K> > > ,
+        new OneBinaryOperator<set_eq_array_mul<KN_<K> ,Divc_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_mul<KN_<K> ,Mul_KNM_KN_<K> > > ,
         new OneBinaryOperator<set_eq_arraypd_mul<KN_<K> ,Add_Mulc_KN_<K>* > > ,
        //- new OneBinaryOperator<set_eq_arrayp_mul<KN_<K> ,KN<K>* > >       
@@ -1237,6 +1261,7 @@ void ArrayOperator()
         new OneBinaryOperator<set_eq_array_div<KN_<K> ,Add_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_div<KN_<K> ,Sub_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_div<KN_<K> ,Mulc_KN_<K> > > ,
+        new OneBinaryOperator<set_eq_array_div<KN_<K> ,Divc_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_div<KN_<K> ,Mul_KNM_KN_<K> > > ,
         new OneBinaryOperator<set_eq_arraypd_div<KN_<K> ,Add_Mulc_KN_<K>* > > ,
         new OneBinaryOperator<set_eq_array_div<KN_<K> ,KN_<K> > >        
@@ -1258,6 +1283,7 @@ void ArrayOperator()
        new OneBinaryOperator<Op2_sub__n<Add_Mulc_KN_<K>,KN_<K>,Mulc_KN_<K> > >,
        new OneBinaryOperator<Op2_sub__n<Add_Mulc_KN_<K>,Mulc_KN_<K> ,KN_<K> > >
        );
+    
      TheOperators->Add("*",
      //-  new OneBinaryOperator<Op2_mulpc<Mulc_KN_<K>,KN<K>*,K> >,
      //-  new OneBinaryOperator<Op2_mulcp<Mulc_KN_<K>,K,KN<K>*> >,
@@ -1273,6 +1299,11 @@ void ArrayOperator()
              
        );
 
+    TheOperators->Add("/",
+                      new OneBinaryOperator<Op2_divc<Divc_KN_<K>,K,KN_<K> > >,
+                      new OneBinaryOperator<Op2_divc<Mulc_KN_<K>,KN_<K>,K > >
+                      
+                      );
 
 //  nouvel operateur       
      TheOperators->Add("+=",
@@ -1350,8 +1381,9 @@ void ArrayOperator()
     
        
      TheOperators->Add(">>",
-        new OneBinaryOperator<Op_ReadKN<K> >
-      );            
+        new OneBinaryOperator<Op_ReadKN<K> >,
+        new OneBinaryOperator<Op_ReadKNM<K> >
+      );
 
      map_type[typeid(MyMap<String,K>*).name()] = new ForEachType<MyMap<String,K>*>(Initialize<MyMap<String,K> >,Delete<MyMap<String,K> >) ;
          
@@ -1374,7 +1406,6 @@ void ArrayOperator()
 		      new OneOperator2_<KN_<K> ,KN_<K> ,SetArray<K> >(-1,&set_array_) // missing aug 2009 a(:)=1:3 less prioritaire
     );
     
-
 }
 
 template<class R,class A,class B=A,class BB=B>
@@ -1405,27 +1436,27 @@ class  OneOperator1F_KN_ : public OneOperator {
 template<class K,class KK>
 void ArrayOperatorF()
 {
-     Dcl_Type<F_KN_<K,K,KK> >();
+     Dcl_Type<F_KN_<K,K,K,KK> >();
 
 
-     Global.Add("exp","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(exp));
-     Global.Add("log","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(log));
-     Global.Add("log10","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(log10));
-     Global.Add("sqrt","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(sqrt));
-     Global.Add("sin","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(sin));
-     Global.Add("cos","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(cos));
-     Global.Add("tan","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(tan));
-     Global.Add("cosh","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(cosh));
-     Global.Add("sinh","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(sinh));
-     Global.Add("tanh","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(tanh));
-    // Global.Add("acos","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(acos));
-    // Global.Add("asin","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(asin));
-    // Global.Add("atan","(",new OneOperator1F_KN_<F_KN_<K,K,KK>,K,KK,KN_<K> >(atan));
+     Global.Add("exp","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(exp));
+     Global.Add("log","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(log));
+     Global.Add("log10","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(log10));
+     Global.Add("sqrt","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(sqrt));
+     Global.Add("sin","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(sin));
+     Global.Add("cos","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(cos));
+     Global.Add("tan","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(tan));
+     Global.Add("cosh","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(cosh));
+     Global.Add("sinh","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(sinh));
+     Global.Add("tanh","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(tanh));
+    // Global.Add("acos","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(acos));
+    // Global.Add("asin","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(asin));
+    // Global.Add("atan","(",new OneOperator1F_KN_<F_KN_<K,K,K,KK>,K,KK,KN_<K> >(atan));
 
-     TheOperators->Add("=",new OneBinaryOperator<set_eq_array<KN_<K> ,F_KN_<K,K,KK> > > ); // add FH juin 2005
-     TheOperators->Add("+=",new OneBinaryOperator<set_eq_array_add<KN_<K> ,F_KN_<K,K,KK> > > ); // add FH juin 2005
-     TheOperators->Add("-=",new OneBinaryOperator<set_eq_array_sub<KN_<K> ,F_KN_<K,K,KK> > > ); // add FH juin 2005
-     TheOperators->Add("/=",new OneBinaryOperator<set_eq_array_div<KN_<K> ,F_KN_<K,K,KK> > > ); // add FH juin 2005
-     TheOperators->Add("*=",new OneBinaryOperator<set_eq_array_mul<KN_<K> ,F_KN_<K,K,KK> > > ); // add FH juin 2005
+     TheOperators->Add("=",new OneBinaryOperator<set_eq_array<KN_<K> ,F_KN_<K,K,K,KK> > > ); // add FH juin 2005
+     TheOperators->Add("+=",new OneBinaryOperator<set_eq_array_add<KN_<K> ,F_KN_<K,K,K,KK> > > ); // add FH juin 2005
+     TheOperators->Add("-=",new OneBinaryOperator<set_eq_array_sub<KN_<K> ,F_KN_<K,K,K,KK> > > ); // add FH juin 2005
+     TheOperators->Add("/=",new OneBinaryOperator<set_eq_array_div<KN_<K> ,F_KN_<K,K,K,KK> > > ); // add FH juin 2005
+     TheOperators->Add("*=",new OneBinaryOperator<set_eq_array_mul<KN_<K> ,F_KN_<K,K,K,KK> > > ); // add FH juin 2005
   
 }
