@@ -337,7 +337,7 @@ AnyType SetMesh_Op::operator()(Stack stack)  const
 	}
 	
       int l0,l1=ChangeLab(mape,l0=m->bedges[i].lab) ;
-      mp->set(Th,Th[k](PtHat),PtHat,Th[i],l1);
+      mp->set(Th,Th[k](PtHat),PtHat,Th[k],l1);
       if(flab)
       {
           R2 E=K.Edge(ke);
