@@ -80,7 +80,7 @@ class classBuildMesh :  public E_F0mps { public:
    typedef pmesh  Result;
 
    static basicAC_F0::name_and_type name_param[] ;
-   static const int n_name_param =2;
+   static const int n_name_param =3;
    
     Expression nargs[n_name_param];
    
@@ -88,6 +88,7 @@ class classBuildMesh :  public E_F0mps { public:
    
    long arg(int i,Stack stack,long a) const{ return nargs[i] ? GetAny<long>( (*nargs[i])(stack) ): a;}
    bool arg(int i,Stack stack,bool a) const{ return nargs[i] ? GetAny<bool>( (*nargs[i])(stack) ): a;}
+   KNM<double>* arg(int i,Stack stack,KNM<double>* p) const{ return nargs[i] ? GetAny<KNM<double>*>( (*nargs[i])(stack) ): p;}
     
     classBuildMesh(const basicAC_F0 & args) 
     {   
@@ -193,7 +194,8 @@ class classBuildMeshArray :  public E_F0mps { public:
 
 basicAC_F0::name_and_type  classBuildMesh::name_param[]= {
     {  "nbvx", &typeid(long)} ,
-    {"fixeborder", &typeid(bool)}  
+    {"fixeborder", &typeid(bool)},
+    {"points", &typeid(KNM<double>*)}
 };
 // modif aout 2007
 class BuildMeshFile :  public E_F0mps { public:  
@@ -482,9 +484,9 @@ AnyType classBuildMesh::operator()(Stack stack)  const {
     const E_BorderN * borders = GetAny<const E_BorderN *>((*getborders)(stack));
    long  nbvx         = arg(0,stack,0L); 
    bool  requireborder=  arg(1,stack,false);
+    KNM<double> * p=0;  p=arg(2,stack,p);
    ffassert(   nbvx >= 0);
-   
-   return SetAny<pmesh>(Add2StackOfPtr2FreeRC(stack,BuildMesh(stack,borders,false,nbvx,requireborder)));
+   return SetAny<pmesh>(Add2StackOfPtr2FreeRC(stack,BuildMesh(stack,borders,false,nbvx,requireborder,p)));
 
 }
 
@@ -1890,6 +1892,43 @@ double volumelevelset(Mesh3 * const & pTh,KN<double> * const &pphi,const double
 }
 double volumelevelset(Mesh3 * const &pTh,KN<double> * const &pphi,const double & phi0) {return volumelevelset(pTh,pphi,phi0,0);}
 
+long Boundingbox(KN<double>* const& pb, pmesh const& pTh)
+{
+     KN<double> & bb =*pb;
+     if(pTh && bb.N()>=4)
+     {
+         R2 Pn,Px;
+         pTh->BoundingBox(Pn,Px);
+         bb[0] = Pn.x;
+         bb[1] = Px.x;
+         bb[2] = Pn.y;
+         bb[3] = Px.y;
+         return 0;
+     }
+    return -1; // error
+}
+long Boundingbox(KN<double>* const& pb, pmesh3 const& pTh)
+{
+    KN<double> & bb =*pb;
+    if(pTh && bb.N()>=6)
+    {
+        R3 Pn=pTh->Pmin,Px=pTh->Pmax  ;
+        bb[0] = Pn.x;
+        bb[1] = Px.x;
+        bb[2] = Pn.y;
+        bb[3] = Px.y;
+        bb[4] = Pn.z;
+        bb[5] = Px.z;
+        return 0;
+     }
+    return -1; // error
+}
+
+long Boundingbox(pmesh3 const& pTh,KN<double>* const& pb )
+{ return  Boundingbox(pb,pTh);}
+long Boundingbox(pmesh const& pTh,KN<double>* const& pb )
+{ return  Boundingbox(pb,pTh);}
+
 
 
 void init_lgmesh() {
@@ -1929,6 +1968,11 @@ void init_lgmesh() {
     //Global.Add("convectlevelset","(", new OneOperatorCode<ConvectLevelSet0 >( ));
     Global.Add("volumelevelset","(",new OneOperator3_<double,Mesh3 *,KN<double>*,double>(volumelevelset));
     Global.Add("volumelevelset","(",new OneOperator4_<double,Mesh3*,KN<double>*,double,KN<double>*>(volumelevelset));
+    // add FH to get bounding box ...
+    Global.Add("boundingbox", "(", new OneOperator2_<long, KN<double>*, pmesh>(Boundingbox));
+    Global.Add("boundingbox", "(", new OneOperator2_<long, KN<double>*, pmesh3>(Boundingbox));
+    Global.Add("boundingbox", "(", new OneOperator2_<long, pmesh,KN<double>*>(Boundingbox));
+    Global.Add("boundingbox", "(", new OneOperator2_<long, pmesh3,KN<double>*>(Boundingbox));
 
   TheOperators->Add("<-",
 		    new OneOperator2_<pmesh*,pmesh*,pmesh >(&set_copy_incr));
