@@ -35,10 +35,12 @@ namespace  Fem2D {
   template<class K> class SolveGCPrecon;
   template<class K> class SolveGMRESPrecon;
   template<class K> class SolveGMRESDiag;
-  int IsoLineK(double *f,R2 *Q,double eps);
+//  int IsoLineK(double *f,R2 *Q,double eps);
   
 }
 
+#include "P1IsoValue.hpp"
+
 
 template<class K> class SolveGCDiag; 
 class Plot;
@@ -246,7 +248,7 @@ class BC_set : public E_F0mps { public:
     {
       aType rr =  complextype ? atype<Complex>() : atype<double>();
       if (rr == atype<Complex>()) complextype= true; 
-      cout << " CastToK => " << complextype <<endl;
+      if(verbosity > 10) cout << " CastToK => " << complextype <<endl;
      for ( vector<pair<int,Expression> >::iterator k=bc.begin();k!=bc.end();k++)
 	k->second=CastTo<K>(C_F0(k->second,rr)) ;
     }
@@ -312,7 +314,7 @@ public:
   const Fem2D::QuadratureFormular & FIT(Stack) const ;   
   const Fem2D::QuadratureFormular1d & FIE(Stack) const ;  
   const Fem2D::GQuadratureFormular<R3> & FIV(Stack) const ;  // 3d
-  bool UseOpt(Stack s) const  {  return nargs[5] ? GetAny<bool>( (*(nargs[5]))(s) )  : 1;}
+  long UseOpt(Stack s) const  {  return nargs[5] ? GetAny<long>( (*(nargs[5]))(s) )  : 1;}
   double  binside(Stack s) const { return nargs[6] ? GetAny<double>( (*(nargs[6]))(s) )  : 0;} // truc pour FH
   bool intmortar(Stack s) const { return nargs[7] ? GetAny<bool>( (*(nargs[7])) (s) )  : 1;} // truc  pour 
   double levelset(Stack s) const { return nargs[9] ? GetAny<double>( (*(nargs[9]))(s) )  : 0;}
@@ -873,7 +875,7 @@ public:
 
 
 
-template<class K> class Matrice_Creuse  { 
+template<class K> class Matrice_Creuse  {
   //  CountPointer<FESpace> Uh,Vh;
   //pfes  *pUh,*pVh; // pointeur sur la variable stockant FESpace;  
 public:
@@ -881,12 +883,16 @@ public:
   //  const void * pUh,pVh; //  pointeur pour la reconstruction 
   CountPointer<MatriceCreuse<K> > A;  
   TypeSolveMat typemat;
+    size_t count;
   void init() {
+      count=0;
     A.init();Uh.init();Vh.init();
     typemat=TypeSolveMat(TypeSolveMat::NONESQUARE);}
   Matrice_Creuse() { init();}
-  void destroy() {
-    A.destroy();
+  void destroy() {// Correct Oct 2015 FH (avant test a 'envert) !!!!
+    if(count--==0)
+      A.destroy();
+//else count--;
     //    Uh.destroy();
     //Vh.destroy();
   }   
@@ -897,7 +903,7 @@ public:
   long N() const {return  A ? A->n : 0;}
   long M() const { return A ? A->m : 0;}
   void resize(int n,int m) { if(A) A->resize(n,m);}
-  
+  void increment(){ count++;}
 };
 
 template<class K> class Matrice_Creuse_Transpose;
@@ -994,10 +1000,10 @@ namespace Fem2D {
   template<class R>   void AssembleBC(Stack stack,const Mesh & Th3,const FESpace & Uh3,const FESpace & Vh3,bool sym,
 				      MatriceCreuse<R>  * A,KN_<R> * B,KN_<R> * X, const  BC_set * bc , double tgv   );
   
-  template<class R>   void  Element_rhs(const FElement3 & Kv,int ie,int label,const LOperaD &Op,double * p,void * stack,KN_<R> & B,bool all);
-  template<class R>   void  Element_rhs(const FElement3 & Kv,const LOperaD &Op,double * p,void * stack,KN_<R> & B);
-  template<class R>   void  Element_Op(MatriceElementairePleine<R,FESpace3> & mat,const FElement3 & Ku,const FElement3 & Kv,double * p,int ie,int label, void *stack);
-  template<class R>   void  Element_Op(MatriceElementaireSymetrique<R,FESpace3> & mat,const FElement3 & Ku,double * p,int ie,int label, void * stack);
+  template<class R>   void  Element_rhs(const FElement3 & Kv,int ie,int label,const LOperaD &Op,double * p,void * stack,KN_<R> & B,bool all,int optim);
+  template<class R>   void  Element_rhs(const FElement3 & Kv,const LOperaD &Op,double * p,void * stack,KN_<R> & B,int optim);
+  template<class R>   void  Element_Op(MatriceElementairePleine<R,FESpace3> & mat,const FElement3 & Ku,const FElement3 & Kv,double * p,int ie,int label, void *stack,R3 *B);
+  template<class R>   void  Element_Op(MatriceElementaireSymetrique<R,FESpace3> & mat,const FElement3 & Ku,double * p,int ie,int label, void * stack,R3 *B);
   
   template<class R,class FESpace>
   void AssembleBC(Stack stack,const typename FESpace::Mesh & Th,const FESpace & Uh,const FESpace & Vh,bool sym,
@@ -1005,10 +1011,10 @@ namespace Fem2D {
   
   // fin 3d 
   
-  template<class R>   void  Element_rhs(const FElement & Kv,int ie,int label,const LOperaD &Op,double * p,void * stack,KN_<R> & B,bool all);
-  template<class R>   void  Element_rhs(const FElement & Kv,const LOperaD &Op,double * p,void * stack,KN_<R> & B);
-  template<class R>   void  Element_Op(MatriceElementairePleine<R,FESpace> & mat,const FElement & Ku,const FElement & Kv,double * p,int ie,int label, void *stack);
-  template<class R>   void  Element_Op(MatriceElementaireSymetrique<R,FESpace> & mat,const FElement & Ku,double * p,int ie,int label, void * stack);
+  template<class R>   void  Element_rhs(const FElement & Kv,int ie,int label,const LOperaD &Op,double * p,void * stack,KN_<R> & B,bool all,int optim);
+  template<class R>   void  Element_rhs(const FElement & Kv,const LOperaD &Op,double * p,void * stack,KN_<R> & B,int optim);
+  template<class R>   void  Element_Op(MatriceElementairePleine<R,FESpace> & mat,const FElement & Ku,const FElement & Kv,double * p,int ie,int label, void *stack,R2 *B);
+  template<class R>   void  Element_Op(MatriceElementaireSymetrique<R,FESpace> & mat,const FElement & Ku,double * p,int ie,int label, void * stack,R2 *B);
   
 /*template<class R>   void AssembleBilinearForm(Stack stack,const Mesh & Th,const FESpace & Uh,const FESpace & Vh,bool sym,
                             MatriceCreuse<R>  & A, const  FormBilinear * b  );
