@@ -18,6 +18,6 @@ string StrVersionNumber(){
 //  buffer.precision(8);
 //  buffer<<VersionNumber();
   static char buffer[100];
-  sprintf(buffer," %9f (date Ven 22 mai 2015 13:48:50 CEST)",VersionNumber());
-  return buffer; //.str()+" (date Ven 22 mai 2015 13:48:50 CEST)" ;
+  sprintf(buffer," %9f (date Lun 29 jui 2015 15:34:41 CEST)",VersionNumber());
+  return buffer; //.str()+" (date Lun 29 jui 2015 15:34:41 CEST)" ;
 }
